# A helper class to test the ensure_resources function
class test::ensure_resources( $resource_type, $title_hash, $attributes_hash ) {
  ensure_resources($resource_type, $title_hash, $attributes_hash)
}
